macro_rules! c_wrapper {
($c_name:ident, $rust_type:ty) => { ... };
}Expand description
Macro to generate C wrapper struct for a Rust type
macro_rules! c_wrapper {
($c_name:ident, $rust_type:ty) => { ... };
}Macro to generate C wrapper struct for a Rust type